ziggy.GraphReduce.LostMass_reducer

Package ziggy :: Package GraphReduce :: Module LostMass_reducer |
[hide private]
[frames] | no frames]

# Source Code for Module ziggy.GraphReduce.LostMass_reducer

     1  #! /usr/bin/env python
     2  '''
     3  Created on Aug 18, 2010
     4
     5  @author: dwmclary
     6  '''
     7  import sys
     8 -def read_map_output(file):
     9      for line in file:
    10          yield line
    11 -def main():
    12      data = read_map_output(sys.stdin)
    13      for line in data:
    14          print line.strip()
    15
    16
    17  if __name__ == "__main__":
    18      try:
    19          import psyco
    20          psyco.full()
    21      except:
    22          pass
    23      main()
    24